@@ -22,6 +22,7 @@ from sqlalchemy.orm.exc import MultipleResultsFound, NoResultFound
 
 from tropofy.database import DBSession
 from tropofy.database.tropofy_orm import json_renderer, DynamicSchemaName
+from tropofy.file_io import FileIoConfig
 
 
 def main(global_config, **settings):
@@ -95,13 +96,15 @@ def main(global_config, **settings):
     config.add_renderer('json', json_renderer)  # Custom json renderer.
 
     config.include(addroutes)
-    config.scan()  # Scans for @view_config decorators to register views.
+    config.scan(package='tropofy.views')  # Scans for @view_config decorators to register views.
 
     AppManager.add_additional_absolute_paths_to_python_path(settings.get('custom.additional_absolute_paths_to_add_to_python_path'))
     AppManager.initialise_apps(settings['custom.apps_directory'])
     for app in LoadedApps.apps.values():
         config.add_static_view('apps_static/%s' % app.url_name, app.app_folder_path, cache_max_age=1)
 
+    FileIoConfig.aws_s3_bucket_name = settings.get('custom.aws_s3_bucket')
+
     transaction.commit()
 
     if App.overridden_global_sqla_engine:
