@@ -55,10 +55,12 @@ class AppManager(object):
         for dir_ in dirs:
             path, module_name = os.path.split(dir_)
             DynamicSchemaName.set_schema_name(module_name)
-
             sys.path.append(path)
+
+            module = importlib.import_module(module_name)  # Importing the module here gives it the chance to set a custom value for DynamicSchemaName.schema_name
+
             AppManager._create_app_if_possible(
-                possible_app_package=importlib.import_module(module_name),
+                possible_app_package=module,
                 possible_app_schema_name=DynamicSchemaName.schema_name,
                 possible_app_package_file_path=dir_,
             )
@@ -85,21 +87,21 @@ class AppManager(object):
             LoadedApps.apps[app.url_name] = app
             cls._setup_app_db_tables(app)
 
-    @staticmethod
-    def _get_app_interface_from_module(imported_package):
+    @classmethod
+    def _get_app_interface_from_module(cls, imported_package):
         """
-
-        :param possible_app_package: A Python package that may contain an App (even though a package, is of type module)
-        :type  possible_app_package: Python module
         :return: tropofy.application.App or None, if no App could be created from the package.
         """
-        app = None
         for class_name, class_type in inspect.getmembers(imported_package, inspect.isclass):
             if class_type not in [App, AppWithDataSets] and App in inspect.getmro(class_type):
-                if app is not None:  # Multiple apps found in single module!
-                    return None
-                app = class_type()
-        return app
+                # Instantiate app
+                return class_type(config=cls._get_config_from_module(imported_package))
+
+    @classmethod
+    def _get_config_from_module(cls, imported_package):
+        for var_name, dict_ in inspect.getmembers(imported_package, lambda x: isinstance(x, dict)):
+            if var_name == "CONFIG":
+                return dict_
 
     @classmethod
     def _setup_app_db_tables(cls, app):
