@@ -71,7 +71,7 @@ def run_app(request):
 def redirect_to_run_app(request):
     if request.only_app:
         return exc.HTTPFound(
-            location=request.route_url('run_app', app_url_name=request.only_app.url_name)
+            location=request.route_url('run_app', app_url_name=request.only_app.url_name, _scheme=request.scheme, _port=request.server_port)  # Must specify port if specify scheme - otherwise breaks
         )
     else:
         raise exc.HTTPNotFound()
@@ -179,6 +179,9 @@ def logout(request):
     headers = forget(request)
 
     mako_render_dict = request.app.get_home_page_configuration()
+    mako_render_dict.update({
+        'login_screen_default_is_create_account': request.app.is_login_screen_default_create_account()
+    })
     data = {'mako_render_dict': mako_render_dict}
     url = request.registry.settings.get('custom.gui_server_url') + '/' + request.app.url_name + '/homepage'
     result = proxy_request(data, url)
@@ -188,7 +191,7 @@ def logout(request):
 @forbidden_view_config(renderer='string')
 def forbidden(request):
     return exc.HTTPFound(
-        location=request.route_url('logout', app_url_name=request.matchdict.get('app_url_name'))
+        location=request.route_url('logout', app_url_name=request.matchdict.get('app_url_name'), _scheme=request.scheme, _port=request.server_port)
     )
 
 
@@ -225,6 +228,7 @@ def check_response_for_success(response):
 
     # (2) Tropofy caught failure
     success = True
+    message = ""
     try:
         response = json.loads(response.text)
         success = response.get('success')
