@@ -376,3 +376,40 @@ class Filter(Form):
             data=defaults,
             data_set=data_set
         )
+
+
+class FilterMixin(object):
+    """FilterMixin can be inherited from to link a widget to a :class:`tropofy.widgets.Filter`.
+
+    Any widget inheriting from FilterMixin gets a constructor with a ``data_filter`` parameter and the helper function :func:`tropofy.widgets.FilteredChart.get_filter_values`.
+
+    If you want to provide your own __init__, be sure to call :func:`tropofy.widgets.FilteredWidget.__init__` from within it.
+
+    .. note:: It is important to inherit from FilterMixin before inheriting from another Widget. Otherwise the relationship to the filter may not work correctly.
+
+    :param data_filter: A filter widget that filters this chart.
+    :type data_filter: :class:`tropofy.widgets.Filter`
+    """
+    def __init__(self, data_filter):
+        self.filter = data_filter
+        if self.filter:
+            self.filter.add_event_subscription('refreshed', self.actions('show'))  # After filter initially loaded('refreshed'), show the chart.
+            self.filter.add_event_subscription('formSubmitSuccess', self.actions('refresh'))
+
+    def get_filter_values(self, data_set):
+        """Helper method that returns the values of the filter.
+
+        Use this method within any methods of your widget with ``self.get_filter_values(data_set)``.
+
+        :param data_set: The DataSet object on which queries can be made to access the apps data.
+        :type data_set: :class:`tropofy.app.AppDataSet`
+
+        :rtype: dict representation of the filtered values
+        """
+        try:
+            return self.filter.get_values(data_set)
+        except AttributeError:  # No filter.
+            return {}
+
+    def is_hidden(self):  # Makes widget hidden onload. Filter will trigger to show it when ready. Stops chart getting loaded incorrectly before filtered vars are set. If no filter, no need to hide chart.
+        return self.filter is not None
\ No newline at end of file
