@@ -89,6 +89,16 @@ class Widget(object):
         """
         return False
 
+    def get_unique_name(self):
+        """Return a name for the widget that is unique in this app.
+
+         This name can be used to uniquely reference the widget in database tables. This is used by :class:`tropofy.widgets.ExecuteFunction` to store task history relative to a widget.
+
+        .. warning: It is up to the developer to ensure names are unique across widgets in an app. If this method is not supplied, the default is an auto generated ID which will change
+         when widgets are added or moved in the workflow. This can be confusing in development, and limits the ability to quickly change production apps without confusion.
+         """
+        return str(self.id)
+
     def serialise(self):
         '''Dict representation for easy conversion to JSON.'''        
         event_subscriptions = self.event_subscriptions if hasattr(self, 'event_subscriptions') else {}
